# =====================================
# generator=datazen
# version=3.1.4
# hash=77469656d16b7bf1c6cca1d91d73eec9
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A tool for working with scalable vector graphics."
PKG_NAME = "svgen"
VERSION = "0.6.5"
